==> 1.1.1.tar.gz: lib/src/emojis/symbols.dart <==
List symbolsList = [
  ['Heart with Arrow', '💘'],
  ['Heart with Ribbon', '💝'],
  ['Sparkling Heart', '💖'],
  ['Growing Heart', '💗'],
  ['Beating Heart', '💓'],
  ['Revolving Hearts', '💞'],
  ['Two Hearts', '💕'],
  ['Heart Decoration', '💟'],
  ['Heart Exclamation', '❣️'],
  ['Broken Heart', '💔'],
  ['Heart on Fire', '❤️‍🔥'],
  ['Mending Heart', '❤️‍🩹'],
  ['Red Heart', '❤️'],
  ['Orange Heart', '🧡'],
  ['Yellow Heart', '💛'],
  ['Green Heart', '💚'],
  ['Blue Heart', '💙'],
  ['Purple Heart', '💜'],
  ['Brown Heart', '🤎'],
  ['Black Heart', '🖤'],
  ['White Heart', '🤍'],
  ['Hundred Points', '💯'],
  ['Anger Symbol', '💢'],
  ['Speech Balloon', '💬'],
  ['Eye in Speech Bubble', '👁️‍🗨️'],
  ['Left Speech Bubble', '🗨️'],
  ['Right Anger Bubble', '🗯️'],
  ['Thought Balloon', '💭'],
  ['Zzz', '💤'],
  ['White Flower', '💮'],
  ['Hot Springs', '♨️'],
  ['Barber Pole', '💈'],
  ['Stop Sign', '🛑'],
  ['Twelve O’Clock', '🕛'],
  ['Twelve-Thirty', '🕧'],
  ['One O’Clock', '🕐'],
  ['One-Thirty', '🕜'],
  ['Two O’Clock', '🕑'],
  ['Two-Thirty', '🕝'],
  ['Three O’Clock', '🕒'],
  ['Three-Thirty', '🕞'],
  ['Four O’Clock', '🕓'],
  ['Four-Thirty', '🕟'],
  ['Five O’Clock', '🕔'],
  ['Five-Thirty', '🕠'],
  ['Six O’Clock', '🕕'],
  ['Six-Thirty', '🕡'],
  ['Seven O’Clock', '🕖'],
  ['Seven-Thirty', '🕢'],
  ['Eight O’Clock', '🕗'],
  ['Eight-Thirty', '🕣'],
  ['Nine O’Clock', '🕘'],
  ['Nine-Thirty', '🕤'],
  ['Ten O’Clock', '🕙'],
  ['Ten-Thirty', '🕥'],
  ['Eleven O’Clock', '🕚'],
  ['Eleven-Thirty', '🕦'],
  ['Cyclone', '🌀'],
  ['Spade Suit', '♠️'],
  ['Heart Suit', '♥️'],
  ['Diamond Suit', '♦️'],
  ['Club Suit', '♣️'],
  ['Joker', '🃏'],
  ['Mahjong Red Dragon', '🀄'],
  ['Flower Playing Cards', '🎴'],
  ['Muted Speaker', '🔇'],
  ['Speaker Low Volume', '🔈'],
  ['Speaker Medium Volume', '🔉'],
  ['Speaker High Volume', '🔊'],
  ['Loudspeaker', '📢'],
  ['Megaphone', '📣'],
  ['Postal Horn', '📯'],
  ['Bell', '🔔'],
  ['Bell with Slash', '🔕'],
  ['Musical Note', '🎵'],
  ['Musical Notes', '🎶'],
  ['Chart Increasing with Yen', '💹'],
  ['Elevator', '🛗'],
  ['ATM Sign', '🏧'],
  ['Litter in Bin Sign', '🚮'],
  ['Potable Water', '🚰'],
  ['Wheelchair Symbol', '♿'],
  ['Men’s Room', '🚹'],
  ['Women’s Room', '🚺'],
  ['Restroom', '🚻'],
  ['Baby Symbol', '🚼'],
  ['Water Closet', '🚾'],
  ['Warning', '⚠️'],
  ['Children Crossing', '🚸'],
  ['No Entry', '⛔'],
  ['Prohibited', '🚫'],
  ['No Bicycles', '🚳'],
  ['No Smoking', '🚭'],
  ['No Littering', '🚯'],
  ['Non-Potable Water', '🚱'],
  ['No Pedestrians', '🚷'],
  ['No Mobile Phones', '📵'],
  ['No One Under Eighteen', '🔞'],
  ['Radioactive', '☢️'],
  ['Biohazard', '☣️'],
  ['Up Arrow', '⬆️'],
  ['Up-Right Arrow', '↗️'],
  ['Right Arrow', '➡️'],
  ['Down-Right Arrow', '↘️'],
  ['Down Arrow', '⬇️'],
  ['Down-Left Arrow', '↙️'],
  ['Left Arrow', '⬅️'],
  ['Up-Left Arrow', '↖️'],
  ['Up-Down Arrow', '↕️'],
  ['Left-Right Arrow', '↔️'],
  ['Right Arrow Curving Left', '↩️'],
  ['Left Arrow Curving Right', '↪️'],
  ['Right Arrow Curving Up', '⤴️'],
  ['Right Arrow Curving Down', '⤵️'],
  ['Clockwise Vertical Arrows', '🔃'],
  ['Counterclockwise Arrows Button', '🔄'],
  ['Back Arrow', '🔙'],
  ['End Arrow', '🔚'],
  ['On! Arrow', '🔛'],
  ['Soon Arrow', '🔜'],
  ['Top Arrow', '🔝'],
  ['Place of Worship', '🛐'],
  ['Atom Symbol', '⚛️'],
  ['Om', '🕉️'],
  ['Star of David', '✡️'],
  ['Wheel of Dharma', '☸️'],
  ['Yin Yang', '☯️'],
  ['Latin Cross', '✝️'],
  ['Orthodox Cross', '☦️'],
  ['Star and Crescent', '☪️'],
  ['Peace Symbol', '☮️'],
  ['Menorah', '🕎'],
  ['Dotted Six-Pointed Star', '🔯'],
  ['Aries', '♈'],
  ['Taurus', '♉'],
  ['Gemini', '♊'],
  ['Cancer', '♋'],
  ['Leo', '♌'],
  ['Virgo', '♍'],
  ['Libra', '♎'],
  ['Scorpio', '♏'],
  ['Sagittarius', '♐'],
  ['Capricorn', '♑'],
  ['Aquarius', '♒'],
  ['Pisces', '♓'],
  ['Ophiuchus', '⛎'],
  ['Shuffle Tracks Button', '🔀'],
  ['Repeat Button', '🔁'],
  ['Repeat Single Button', '🔂'],
  ['Play Button', '▶️'],
  ['Fast-Forward Button', '⏩'],
  ['Next Track Button', '⏭️'],
  ['Play or Pause Button', '⏯️'],
  ['Reverse Button', '◀️'],
  ['Fast Reverse Button', '⏪'],
  ['Last Track Button', '⏮️'],
  ['Upwards Button', '🔼'],
  ['Fast Up Button', '⏫'],
  ['Downwards Button', '🔽'],
  ['Fast Down Button', '⏬'],
  ['Pause Button', '⏸️'],
  ['Stop Button', '⏹️'],
  ['Record Button', '⏺️'],
  ['Eject Button', '⏏️'],
  ['Cinema', '🎦'],
  ['Dim Button', '🔅'],
  ['Bright Button', '🔆'],
  ['Antenna Bars', '📶'],
  ['Vibration Mode', '📳'],
  ['Mobile Phone Off', '📴'],
  ['Female Sign', '♀️'],
  ['Male Sign', '♂️'],
  ['Multiply', '✖️'],
  ['Plus', '➕'],
  ['Minus', '➖'],
  ['Divide', '➗'],
  ['Infinity', '♾️'],
  ['Double Exclamation Mark', '‼️'],
  ['Exclamation Question Mark', '⁉️'],
  ['Question Mark', '❓'],
  ['White Question Mark', '❔'],
  ['White Exclamation Mark', '❕'],
  ['Exclamation Mark', '❗'],
  ['Wavy Dash', '〰️'],
  ['Currency Exchange', '💱'],
  ['Heavy Dollar Sign', '💲'],
  ['Medical Symbol', '⚕️'],
  ['Recycling Symbol', '♻️'],
  ['Fleur-de-lis', '⚜️'],
  ['Trident Emblem', '🔱'],
  ['Name Badge', '📛'],
  ['Japanese Symbol for Beginner', '🔰'],
  ['Hollow Red Circle', '⭕'],
  ['Check Mark Button', '✅'],
  ['Check Box with Check', '☑️'],
  ['Check Mark', '✔️'],
  ['Cross Mark', '❌'],
  ['Cross Mark Button', '❎'],
  ['Curly Loop', '➰'],
  ['Double Curly Loop', '➿'],
  ['Part Alternation Mark', '〽️'],
  ['Eight-Spoked Asterisk', '✳️'],
  ['Eight-Pointed Star', '✴️'],
  ['Sparkle', '❇️'],
  ['Copyright', '©️'],
  ['Registered', '®️'],
  ['Trade Mark', '™️'],
  ['Keycap Number Sign', '#️⃣'],
  ['Keycap Asterisk', '*️⃣'],
  ['Keycap Digit Zero', '0️⃣'],
  ['Keycap Digit One', '1️⃣'],
  ['Keycap Digit Two', '2️⃣'],
  ['Keycap Digit Three', '3️⃣'],
  ['Keycap Digit Four', '4️⃣'],
  ['Keycap Digit Five', '5️⃣'],
  ['Keycap Digit Six', '6️⃣'],
  ['Keycap Digit Seven', '7️⃣'],
  ['Keycap Digit Eight', '8️⃣'],
  ['Keycap Digit Nine', '9️⃣'],
  ['Keycap: 10', '🔟'],
  ['Input Latin Uppercase', '🔠'],
  ['Input Latin Lowercase', '🔡'],
  ['Input Numbers', '🔢'],
  ['Input Symbols', '🔣'],
  ['Input Latin Letters', '🔤'],
  ['A Button (Blood Type)', '🅰️'],
  ['AB Button (Blood Type)', '🆎'],
  ['B Button (Blood Type)', '🅱️'],
  ['CL Button', '🆑'],
  ['Cool Button', '🆒'],
  ['Free Button', '🆓'],
  ['Information', 'ℹ️'],
  ['ID Button', '🆔'],
  ['Circled M', 'Ⓜ️'],
  ['New Button', '🆕'],
  ['NG Button', '🆖'],
  ['O Button (Blood Type)', '🅾️'],
  ['OK Button', '🆗'],
  ['P Button', '🅿️'],
  ['SOS Button', '🆘'],
  ['Up! Button', '🆙'],
  ['Vs Button', '🆚'],
  ['Japanese “Here” Button', '🈁'],
  ['Japanese “Service Charge” Button', '🈂️'],
  ['Japanese “Monthly Amount” Button', '🈷️'],
  ['Japanese “Not Free of Charge” Button', '🈶'],
  ['Japanese “Reserved” Button', '🈯'],
  ['Japanese “Bargain” Button', '🉐'],
  ['Japanese “Discount” Button', '🈹'],
  ['Japanese “Free of Charge” Button', '🈚'],
  ['Japanese “Prohibited” Button', '🈲'],
  ['Japanese “Acceptable” Button', '🉑'],
  ['Japanese “Application” Button', '🈸'],
  ['Japanese “Passing Grade” Button', '🈴'],
  ['Japanese “Vacancy” Button', '🈳'],
  ['Japanese “Congratulations” Button', '㊗️'],
  ['Japanese “Secret” Button', '㊙️'],
  ['Japanese “Open for Business” Button', '🈺'],
  ['Japanese “No Vacancy” Button', '🈵'],
  ['Red Circle', '🔴'],
  ['Orange Circle', '🟠'],
  ['Yellow Circle', '🟡'],
  ['Green Circle', '🟢'],
  ['Blue Circle', '🔵'],
  ['Purple Circle', '🟣'],
  ['Brown Circle', '🟤'],
  ['Black Circle', '⚫'],
  ['White Circle', '⚪'],
  ['Red Square', '🟥'],
  ['Orange Square', '🟧'],
  ['Yellow Square', '🟨'],
  ['Green Square', '🟩'],
  ['Blue Square', '🟦'],
  ['Purple Square', '🟪'],
  ['Brown Square', '🟫'],
  ['Black Large Square', '⬛'],
  ['White Large Square', '⬜'],
  ['Black Medium Square', '◼️'],
  ['White Medium Square', '◻️'],
  ['Black Medium-Small Square', '◾'],
  ['White Medium-Small Square', '◽'],
  ['Black Small Square', '▪️'],
  ['White Small Square', '▫️'],
  ['Large Orange Diamond', '🔶'],
  ['Large Blue Diamond', '🔷'],
  ['Small Orange Diamond', '🔸'],
  ['Small Blue Diamond', '🔹'],
  ['Red Triangle Pointed Up', '🔺'],
  ['Red Triangle Pointed Down', '🔻'],
  ['Diamond with a Dot', '💠'],
  ['Radio Button', '🔘'],
  ['White Square Button', '🔳'],
  ['Black Square Button', '🔲']
];

==> 1.2.3.tar.gz: lib/src/emojis/symbols.dart <==
List symbolsList = [
  ['Heart with Arrow', '💘'],
  ['Heart with Ribbon', '💝'],
  ['Sparkling Heart', '💖'],
  ['Growing Heart', '💗'],
  ['Beating Heart', '💓'],
  ['Revolving Hearts', '💞'],
  ['Two Hearts', '💕'],
  ['Heart Decoration', '💟'],
  ['Heart Exclamation', '❣️'],
  ['Broken Heart', '💔'],
  ['Heart on Fire', '❤️‍🔥'],
  ['Mending Heart', '❤️‍🩹'],
  ['Red Heart', '❤️'],
  ['Orange Heart', '🧡'],
  ['Yellow Heart', '💛'],
  ['Green Heart', '💚'],
  ['Blue Heart', '💙'],
  ['Purple Heart', '💜'],
  ['Brown Heart', '🤎'],
  ['Black Heart', '🖤'],
  ['White Heart', '🤍'],
  ['Hundred Points', '💯'],
  ['Anger Symbol', '💢'],
  ['Speech Balloon', '💬'],
  ['Eye in Speech Bubble', '👁️‍🗨️'],
  ['Left Speech Bubble', '🗨️'],
  ['Right Anger Bubble', '🗯️'],
  ['Thought Balloon', '💭'],
  ['Zzz', '💤'],
  ['White Flower', '💮'],
  ['Hot Springs', '♨️'],
  ['Barber Pole', '💈'],
  ['Stop Sign', '🛑'],
  ['Twelve O’Clock', '🕛'],
  ['Twelve-Thirty', '🕧'],
  ['One O’Clock', '🕐'],
  ['One-Thirty', '🕜'],
  ['Two O’Clock', '🕑'],
  ['Two-Thirty', '🕝'],
  ['Three O’Clock', '🕒'],
  ['Three-Thirty', '🕞'],
  ['Four O’Clock', '🕓'],
  ['Four-Thirty', '🕟'],
  ['Five O’Clock', '🕔'],
  ['Five-Thirty', '🕠'],
  ['Six O’Clock', '🕕'],
  ['Six-Thirty', '🕡'],
  ['Seven O’Clock', '🕖'],
  ['Seven-Thirty', '🕢'],
  ['Eight O’Clock', '🕗'],
  ['Eight-Thirty', '🕣'],
  ['Nine O’Clock', '🕘'],
  ['Nine-Thirty', '🕤'],
  ['Ten O’Clock', '🕙'],
  ['Ten-Thirty', '🕥'],
  ['Eleven O’Clock', '🕚'],
  ['Eleven-Thirty', '🕦'],
  ['Cyclone', '🌀'],
  ['Spade Suit', '♠️'],
  ['Heart Suit', '♥️'],
  ['Diamond Suit', '♦️'],
  ['Club Suit', '♣️'],
  ['Joker', '🃏'],
  ['Mahjong Red Dragon', '🀄'],
  ['Flower Playing Cards', '🎴'],
  ['Muted Speaker', '🔇'],
  ['Speaker Low Volume', '🔈'],
  ['Speaker Medium Volume', '🔉'],
  ['Speaker High Volume', '🔊'],
  ['Loudspeaker', '📢'],
  ['Megaphone', '📣'],
  ['Postal Horn', '📯'],
  ['Bell', '🔔'],
  ['Bell with Slash', '🔕'],
  ['Musical Note', '🎵'],
  ['Musical Notes', '🎶'],
  ['Chart Increasing with Yen', '💹'],
  ['Elevator', '🛗'],
  ['ATM Sign', '🏧'],
  ['Litter in Bin Sign', '🚮'],
  ['Potable Water', '🚰'],
  ['Wheelchair Symbol', '♿'],
  ['Men’s Room', '🚹'],
  ['Women’s Room', '🚺'],
  ['Restroom', '🚻'],
  ['Baby Symbol', '🚼'],
  ['Water Closet', '🚾'],
  ['Warning', '⚠️'],
  ['Children Crossing', '🚸'],
  ['No Entry', '⛔'],
  ['Prohibited', '🚫'],
  ['No Bicycles', '🚳'],
  ['No Smoking', '🚭'],
  ['No Littering', '🚯'],
  ['Non-Potable Water', '🚱'],
  ['No Pedestrians', '🚷'],
  ['No Mobile Phones', '📵'],
  ['No One Under Eighteen', '🔞'],
  ['Radioactive', '☢️'],
  ['Biohazard', '☣️'],
  ['Up Arrow', '⬆️'],
  ['Up-Right Arrow', '↗️'],
  ['Right Arrow', '➡️'],
  ['Down-Right Arrow', '↘️'],
  ['Down Arrow', '⬇️'],
  ['Down-Left Arrow', '↙️'],
  ['Left Arrow', '⬅️'],
  ['Up-Left Arrow', '↖️'],
  ['Up-Down Arrow', '↕️'],
  ['Left-Right Arrow', '↔️'],
  ['Right Arrow Curving Left', '↩️'],
  ['Left Arrow Curving Right', '↪️'],
  ['Right Arrow Curving Up', '⤴️'],
  ['Right Arrow Curving Down', '⤵️'],
  ['Clockwise Vertical Arrows', '🔃'],
  ['Counterclockwise Arrows Button', '🔄'],
  ['Back Arrow', '🔙'],
  ['End Arrow', '🔚'],
  ['On! Arrow', '🔛'],
  ['Soon Arrow', '🔜'],
  ['Top Arrow', '🔝'],
  ['Place of Worship', '🛐'],
  ['Atom Symbol', '⚛️'],
  ['Om', '🕉️'],
  ['Star of David', '✡️'],
  ['Wheel of Dharma', '☸️'],
  ['Yin Yang', '☯️'],
  ['Latin Cross', '✝️'],
  ['Orthodox Cross', '☦️'],
  ['Star and Crescent', '☪️'],
  ['Peace Symbol', '☮️'],
  ['Menorah', '🕎'],
  ['Dotted Six-Pointed Star', '🔯'],
  ['Aries', '♈'],
  ['Taurus', '♉'],
  ['Gemini', '♊'],
  ['Cancer', '♋'],
  ['Leo', '♌'],
  ['Virgo', '♍'],
  ['Libra', '♎'],
  ['Scorpio', '♏'],
  ['Sagittarius', '♐'],
  ['Capricorn', '♑'],
  ['Aquarius', '♒'],
  ['Pisces', '♓'],
  ['Ophiuchus', '⛎'],
  ['Shuffle Tracks Button', '🔀'],
  ['Repeat Button', '🔁'],
  ['Repeat Single Button', '🔂'],
  ['Play Button', '▶️'],
  ['Fast-Forward Button', '⏩'],
  ['Next Track Button', '⏭️'],
  ['Play or Pause Button', '⏯️'],
  ['Reverse Button', '◀️'],
  ['Fast Reverse Button', '⏪'],
  ['Last Track Button', '⏮️'],
  ['Upwards Button', '🔼'],
  ['Fast Up Button', '⏫'],
  ['Downwards Button', '🔽'],
  ['Fast Down Button', '⏬'],
  ['Pause Button', '⏸️'],
  ['Stop Button', '⏹️'],
  ['Record Button', '⏺️'],
  ['Eject Button', '⏏️'],
  ['Cinema', '🎦'],
  ['Dim Button', '🔅'],
  ['Bright Button', '🔆'],
  ['Antenna Bars', '📶'],
  ['Vibration Mode', '📳'],
  ['Mobile Phone Off', '📴'],
  ['Female Sign', '♀️'],
  ['Male Sign', '♂️'],
  ['Multiply', '✖️'],
  ['Plus', '➕'],
  ['Minus', '➖'],
  ['Divide', '➗'],
  ['Infinity', '♾️'],
  ['Double Exclamation Mark', '‼️'],
  ['Exclamation Question Mark', '⁉️'],
  ['Red Question Mark', '❓'],
  ['White Question Mark', '❔'],
  ['White Exclamation Mark', '❕'],
  ['Red Exclamation Mark', '❗'],
  ['Wavy Dash', '〰️'],
  ['Currency Exchange', '💱'],
  ['Heavy Dollar Sign', '💲'],
  ['Medical Symbol', '⚕️'],
  ['Recycling Symbol', '♻️'],
  ['Fleur-de-lis', '⚜️'],
  ['Trident Emblem', '🔱'],
  ['Name Badge', '📛'],
  ['Japanese Symbol for Beginner', '🔰'],
  ['Hollow Red Circle', '⭕'],
  ['Check Mark Button', '✅'],
  ['Check Box with Check', '☑️'],
  ['Check Mark', '✔️'],
  ['Cross Mark', '❌'],
  ['Cross Mark Button', '❎'],
  ['Curly Loop', '➰'],
  ['Double Curly Loop', '➿'],
  ['Part Alternation Mark', '〽️'],
  ['Eight-Spoked Asterisk', '✳️'],
  ['Eight-Pointed Star', '✴️'],
  ['Sparkle', '❇️'],
  ['Copyright', '©️'],
  ['Registered', '®️'],
  ['Trade Mark', '™️'],
  ['Keycap Number Sign', '#️⃣'],
  ['Keycap Asterisk', '*️⃣'],
  ['Keycap Digit Zero', '0️⃣'],
  ['Keycap Digit One', '1️⃣'],
  ['Keycap Digit Two', '2️⃣'],
  ['Keycap Digit Three', '3️⃣'],
  ['Keycap Digit Four', '4️⃣'],
  ['Keycap Digit Five', '5️⃣'],
  ['Keycap Digit Six', '6️⃣'],
  ['Keycap Digit Seven', '7️⃣'],
  ['Keycap Digit Eight', '8️⃣'],
  ['Keycap Digit Nine', '9️⃣'],
  ['Keycap: 10', '🔟'],
  ['Input Latin Uppercase', '🔠'],
  ['Input Latin Lowercase', '🔡'],
  ['Input Numbers', '🔢'],
  ['Input Symbols', '🔣'],
  ['Input Latin Letters', '🔤'],
  ['A Button (Blood Type)', '🅰️'],
  ['AB Button (Blood Type)', '🆎'],
  ['B Button (Blood Type)', '🅱️'],
  ['CL Button', '🆑'],
  ['Cool Button', '🆒'],
  ['Free Button', '🆓'],
  ['Information', 'ℹ️'],
  ['ID Button', '🆔'],
  ['Circled M', 'Ⓜ️'],
  ['New Button', '🆕'],
  ['NG Button', '🆖'],
  ['O Button (Blood Type)', '🅾️'],
  ['OK Button', '🆗'],
  ['P Button', '🅿️'],
  ['SOS Button', '🆘'],
  ['Up! Button', '🆙'],
  ['Vs Button', '🆚'],
  ['Japanese “Here” Button', '🈁'],
  ['Japanese “Service Charge” Button', '🈂️'],
  ['Japanese “Monthly Amount” Button', '🈷️'],
  ['Japanese “Not Free of Charge” Button', '🈶'],
  ['Japanese “Reserved” Button', '🈯'],
  ['Japanese “Bargain” Button', '🉐'],
  ['Japanese “Discount” Button', '🈹'],
  ['Japanese “Free of Charge” Button', '🈚'],
  ['Japanese “Prohibited” Button', '🈲'],
  ['Japanese “Acceptable” Button', '🉑'],
  ['Japanese “Application” Button', '🈸'],
  ['Japanese “Passing Grade” Button', '🈴'],
  ['Japanese “Vacancy” Button', '🈳'],
  ['Japanese “Congratulations” Button', '㊗️'],
  ['Japanese “Secret” Button', '㊙️'],
  ['Japanese “Open for Business” Button', '🈺'],
  ['Japanese “No Vacancy” Button', '🈵'],
  ['Red Circle', '🔴'],
  ['Orange Circle', '🟠'],
  ['Yellow Circle', '🟡'],
  ['Green Circle', '🟢'],
  ['Blue Circle', '🔵'],
  ['Purple Circle', '🟣'],
  ['Brown Circle', '🟤'],
  ['Black Circle', '⚫'],
  ['White Circle', '⚪'],
  ['Red Square', '🟥'],
  ['Orange Square', '🟧'],
  ['Yellow Square', '🟨'],
  ['Green Square', '🟩'],
  ['Blue Square', '🟦'],
  ['Purple Square', '🟪'],
  ['Brown Square', '🟫'],
  ['Black Large Square', '⬛'],
  ['White Large Square', '⬜'],
  ['Black Medium Square', '◼️'],
  ['White Medium Square', '◻️'],
  ['Black Medium-Small Square', '◾'],
  ['White Medium-Small Square', '◽'],
  ['Black Small Square', '▪️'],
  ['White Small Square', '▫️'],
  ['Large Orange Diamond', '🔶'],
  ['Large Blue Diamond', '🔷'],
  ['Small Orange Diamond', '🔸'],
  ['Small Blue Diamond', '🔹'],
  ['Red Triangle Pointed Up', '🔺'],
  ['Red Triangle Pointed Down', '🔻'],
  ['Diamond with a Dot', '💠'],
  ['Radio Button', '🔘'],
  ['White Square Button', '🔳'],
  ['Black Square Button', '🔲']
];
